export declare class Try<T> {
    private value;
    private executionStack;
    private internalError?;
    private constructor();
    static combine<T extends any[], R>(...args: [...{
        [K in keyof T]: Try<T[K]>;
    }, (...values: T) => R]): Try<R>;
    static success<T>(value: T): Try<T>;
    static failure<T>(error: Error): Try<T>;
    static of<T>(fn: () => T): Try<T>;
    private setValue;
    private setError;
    private executeElement;
    private runExecutionStack;
    run(): Promise<Try<T>>;
    get(): Promise<T>;
    getOrElse<U>(defaultValue: U): Promise<U | T>;
    getOrElseGet<U>(fn: (ex: Error) => U): Promise<T | U>;
    getOrElseThrow<U>(fn: (error: Error) => U): Promise<T | U>;
    map<U>(fn: (value: T) => U): Try<Awaited<U>>;
    flatMap<U>(fn: (value: T) => Try<U>): Try<U>;
    filter(predicateFunc: (value: T) => boolean, throwbackFunction?: (value: T) => void): Try<T>;
    filterNot(predicateFunc: (value: T) => boolean, throwbackFunction?: (value: T) => void): Try<T>;
    peek(fn: (value: T) => void): Try<T>;
    andThen(fn: (value: T) => any): Try<T>;
    recover<U>(fn: (error: Error) => U): Try<T | U>;
    recoverWith<U>(fn: (error: Error) => Try<U>): Try<U | T>;
    isSuccess(): boolean;
    isFailure(): boolean;
    onSuccess(fn: (value: T) => void): Try<T>;
    onFailure(fn: (ex: Error) => void): Try<T>;
    getCause(): Error | undefined;
}
